/**
 * @file includes.h
 * @brief Single file including all necessary system files.
 * @date 12 sep 2017
 * @author Sami Evangelista
 */

#ifndef LIB_INCLUDES
#define LIB_INCLUDES

/*  for pthread_barrier_t and stdio.h */
#define _XOPEN_SOURCE 700

#include "stdio.h"
#include "stdlib.h"
#include "stdarg.h"
#include "limits.h"
#include "pthread.h"
#include "assert.h"
#include "malloc.h"
#include "math.h"
#include "string.h"
#include "limits.h"
#include "sys/times.h"
#include "sys/time.h"
#include "time.h"
#include "unistd.h"
#include "semaphore.h"
#include "signal.h"
#include "stdint.h"

#endif
